@@ -8,6 +8,7 @@ from tempfile import mkdtemp
 
 import mdtraj
 import parmed
+import simtk
 from simtk import openmm as mm
 from simtk.openmm import app
 
@@ -1221,6 +1222,8 @@ class MetadynamicSimulation(MDSimulation):
 
         CVs = build_CVs(self.CV_list,self.parmed_structure,self.system)
 
+        print('initializing simulation with bias factor {}'.format(self.bias_factor))
+
         # build sim
         self.metaD = mm.app.Metadynamics(system=self.system,
                                          variables=CVs,
@@ -1234,6 +1237,28 @@ class MetadynamicSimulation(MDSimulation):
         self.simulation.context.reinitialize()
         self.simulation.context.setPositions(self.positions)
 
+    def _remove_custom_forces(self):
+
+        if self.funnel:
+            self.system.removeForce(self.custom_forces['funnel'])
+        if self.dome:
+            self.system.removeForce(self.custom_forces['flat_bottom_restraint'])
+
+        #CV forces are added via the metaD wrapper so we have to loop over the current forces to find them
+        force_list =self.simulation.system.getForces()
+        force_list_idx = []
+        for k, i in enumerate(force_list):
+            if isinstance(i, simtk.openmm.openmm.CustomCVForce):
+                force_list_idx.append(k)
+
+        for i in force_list_idx:
+            self.system.removeForce(i)
+
+        del self.metaD
+
+        self.simulation.context.reinitialize()
+        self.simulation.context.setPositions(self.positions)
+
 
     def _add_FESReporter(self,fes_interval=None):
         """
@@ -1250,6 +1275,8 @@ class MetadynamicSimulation(MDSimulation):
         if fes_steps == 0:
             raise ValueError('FES interval cannot be zero')
 
+        print('using fes interval steps',fes_steps)
+
         FES_reporter = FESReporter(self.cwd, reportInterval=fes_steps, metaD_wrapper=self.metaD, CV_list=self.CV_list)
         self.simulation.reporters.append(FES_reporter)
 
