@@ -73,18 +73,17 @@ class SegmentMappingSim(MetadynamicSimulation):
         :return: updated parmed.Structure object
         """
 
-        #run initial run with initial biasfactor
-        self.bias_factor = self.scan_bias
-        #segment_coords is a list of chosen coordinates from each replica
-        segment_coords = []
 
-        self._build_sim()
+        self._remove_custom_forces()
+        self.bias_factor = self.scan_bias
         self._build_custom_forces()
 
         print('saving coords')
         initial_coords = self.positions
 
         scan_times = []
+        segment_coords = []
+        chosen_CVs_all_replicas = []
         for i in range(self.num_replicas):
 
             print('Starting scan run for replica {}'.format(i+1))
@@ -95,8 +94,9 @@ class SegmentMappingSim(MetadynamicSimulation):
             nsteps = int(self.scan_time / self.step_length)
 
             #fix the reporter intervals to make sure there are enough frames for populating replicas
+            #this also ensures that the CV value matches the trajectory frame by index
 
-            self._add_reporters(total_steps=nsteps * self.num_replicas, traj_interval= .01 * unit.nanosecond)
+            self._add_reporters(total_steps=nsteps + self.simulation.currentStep, traj_interval= .01 * unit.nanosecond)
             self._add_FESReporter(fes_interval=.01 * unit.nanosecond)
 
             self.metaD.step(self.simulation, nsteps)
@@ -112,7 +112,6 @@ class SegmentMappingSim(MetadynamicSimulation):
 
             scan_clock = self.scan_time
             while all(distances < distances[0]+self.unbound_distance) and  scan_clock<self.max_scan_time:
-                print('min(distances',np.min(distances))
                 print('failed to unbind, scanning for another .5 ns')
                 print('CV distance range {} to {}'.format(np.min(distances),np.max(distances)))
                 scan_clock += .5 * unit.nanosecond
@@ -140,6 +139,7 @@ class SegmentMappingSim(MetadynamicSimulation):
             segment_targets = np.linspace(np.min(distances), self.unbound_distance, self.num_segs)
 
             segment_frames = []
+            chosen_CVs = []
             for target in segment_targets:
                 idx = (np.abs(distances - target)).argmin()
                 #if idx is already in the list, try 100 times to choose another with similar value
@@ -149,11 +149,13 @@ class SegmentMappingSim(MetadynamicSimulation):
                     target+=random.randint(-100,100)* .01
                     idx = (np.abs(distances - target)).argmin()
                 segment_frames.append(idx)
-                print('choosing CV value', distances[idx])
+                chosen_CVs.append(distances[idx])
+                print('choosing CV value {} {}'.format(idx,distances[idx]))
 
             #load trajectory and slice for chosen frames
             traj = mdtraj.load_hdf5(os.path.join(self.cwd,self.traj_out))
             segment_coords.append(traj.xyz[segment_frames])
+            chosen_CVs_all_replicas.append(chosen_CVs)
 
             #now we have the coordinates we use for seeding, get the seg steps and delete the bias file and previous
             #objects
@@ -163,30 +165,38 @@ class SegmentMappingSim(MetadynamicSimulation):
             os.remove(bias_file)
             self.simulation.reporters.clear()
 
+
+        # print(chosen_CVs_all_replicas)
+
         with open(os.path.join(self.cwd,'scan_times.pickle'), 'wb') as handle:
             pickle.dump(scan_times, handle)
 
-        del self.simulation
-        del self.metaD
-        seg_steps = int(self.total_production_time / (self.step_length*self.num_segs*self.num_replicas))
-
+        # remove and rebuild the metaD wrapper force with the new bias factor
+        self._remove_custom_forces()
         self.bias_factor = self.prod_bias
-
-        self._build_sim()
         self._build_custom_forces()
 
-        nsteps = self.total_production_time/self.step_length
-        self._add_reporters(total_steps = nsteps)
+        #get total num steps for reporters
+        nsteps = int(round(self.total_production_time/self.step_length))
+        print('nsteps for production phase',nsteps)
+        self.simulation.reporters = []
+        self._add_reporters(total_steps = nsteps + self.simulation.currentStep)
         self._add_FESReporter()
 
+
+        total_scan_time = np.sum(scan_times)
+
         #loop across all replicas
-        for k,replica in enumerate(range(self.num_replicas)):
-            print('starting replica {}'.format(k+1))
+        for replica in range(self.num_replicas):
+            print('starting replica {}'.format(replica+1))
+            replica_seg_time= scan_times[replica]* (self.total_production_time/(total_scan_time* self.num_segs))
+            replica_seg_steps = int(round(replica_seg_time/self.step_length))
              #loop across the segments with chosen frames running short sims and writing to the bias
             for i,frame in enumerate(segment_coords[replica]):
-                print('swapping in coordinates from replica {} frame {}'.format(k+1,i+1))
+                print('replica {}: swapping in coordinates for CV value {} from frame {}'.format(replica+1,
+                                                    chosen_CVs_all_replicas[replica][i],i+1))
                 self.simulation.context.setPositions(frame * unit.nanometers)
-                self.metaD.step(self.simulation, seg_steps)
+                self.metaD.step(self.simulation, replica_seg_steps)
 
         self.simulation.reporters.clear()
 
